onDeactivate abstract method
Called before component deactivation when routing.
NOTE: This is still called even if the component also extends CanReuse and is reused.
Implementation
void onDeactivate(RouterState current, RouterState next);
Called before component deactivation when routing.
NOTE: This is still called even if the component also extends CanReuse and is reused.
void onDeactivate(RouterState current, RouterState next);