navigate abstract method
Attempts to navigate to a route that matches path.
Query parameters and a fragment identifier can be specified in
navigationParams. If you wish to navigate to a URL that already encodes
these values, see navigateByUrl instead.
Returns a future which completes after navigation indicating whether
navigation completed successfully, failed because no route matched path,
or was blocked by a router lifecycle implementor.
Implementation
Future<NavigationResult> navigate(
String path, [
NavigationParams? navigationParams,
]);