onNavigationStart property
Emits the requested path when navigation starts.
This occurs after all active CanNavigate implementations permit navigation, but before any other router lifecycle method are invoked. Note that this does not necessary indicate the start of a successful navigation, as it could be blocked by another lifecycle implementation or be an invalid request.
Note that for redirected routes, the requested path, not the path it redirects to, is emitted.
Implementation
Stream<String> get onNavigationStart;