replace property
Whether to replace the current history entry or create a new one.
This can be used to replace the current route upon navigation and prevent it from being navigated to again when manipulating browser history.
Implementation
final bool replace;